package com.isu.gaswellwatch.modbus.data.decode.impl;

import cn.hutool.core.map.MapUtil;
import com.isu.gaswellwatch.modbus.data.ModbusMessage;
import com.isu.gaswellwatch.modbus.data.decode.DecodeHandler;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Map;
import java.util.Objects;

/**
 * @author <a href="mailto:shilong.wang@alpha-ess.com">王仕龙</a>
 * 2025/2/24 20:18
 */
@Component(IEEE754DoubleDecodeHandler.NAME + DecodeHandler.DECODE_NAME)
public class IEEE754DoubleDecodeHandler implements DecodeHandler {

    public static final String NAME = "IEEE754Double";

    @Override
    public String decode(Map<String, Object> commandPointMap, String value) {
        if (StringUtils.isBlank(value)) {
            return value;
        }
        // 反向计算：Long.toHexString(Double.doubleToRawLongBits(num))
        value = String.valueOf(Double.longBitsToDouble(Long.parseLong(value, 16)));
        if (Objects.nonNull(commandPointMap) && Objects.nonNull(commandPointMap.get("precision"))) {
            int precision = MapUtil.getInt(commandPointMap, "precision", 0);
            return new BigDecimal(value).setScale(precision, RoundingMode.HALF_UP).toString();
        }
        return value;
    }

    @Override
    public void decode(Map<String, Object> commandPointMap, ModbusMessage.MessagePoint point) {
        point.setValue(this.decode(commandPointMap, MapUtil.getBool(commandPointMap, "use_hex", Boolean.FALSE) ? point.getOriginalValue() : point.getValue()));
    }

}
