package com.isu.gaswellwatch.modbus.data.decode.impl;

import cn.hutool.core.map.MapUtil;
import com.isu.gaswellwatch.modbus.data.ModbusMessage;
import com.isu.gaswellwatch.modbus.data.decode.DecodeHandler;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.math.NumberUtils;
import org.springframework.stereotype.Component;

import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * 本地时间类型解析器
 *
 * @author <a href="mailto:scwsl@foxmail.com">王仕龙</a>
 * 2024/12/09 14:40
 */
@Component(MinuteLocalTimeDecodeHandler.NAME + DecodeHandler.DECODE_NAME)
public class MinuteLocalTimeDecodeHandler implements DecodeHandler {
    public static final String NAME = "minuteLocalTime";

    @Override
    public String decode(Map<String, Object> commandPointMap, String value) {
        if (StringUtils.isNotBlank(value) && NumberUtils.isCreatable(value)) {
            long totalMinutes = NumberUtils.createLong(value);
            long hours = TimeUnit.MINUTES.toHours(totalMinutes);
            long minutes = totalMinutes - TimeUnit.HOURS.toMinutes(hours);
            return String.format("%02d:%02d:00", hours, minutes);
        }
        return value;
    }

    @Override
    public void decode(Map<String, Object> commandPointMap, ModbusMessage.MessagePoint point) {
        point.setValue(this.decode(commandPointMap, MapUtil.getBool(commandPointMap, "use_hex", Boolean.FALSE) ? point.getOriginalValue() : point.getValue()));
    }

}
