package com.isu.gaswellwatch.modbus.data.decode.impl.weps;

import cn.hutool.core.map.MapUtil;
import com.isu.gaswellwatch.modbus.data.ModbusMessage;
import com.isu.gaswellwatch.modbus.data.decode.DecodeHandler;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.Map;

/**
 * @author <a href="mailto:shilong.wang@alpha-ess.com">王仕龙</a>
 * 2025/2/22 00:26
 */
@Component(WepsCurrentLocalDateTimeDecodeHandler.NAME + DecodeHandler.DECODE_NAME)
public class WepsCurrentLocalDateTimeDecodeHandler implements DecodeHandler {

    public static final String NAME = "wepsCurrentLocalDateTime";

    @Override
    public String decode(Map<String, Object> commandPointMap, String value) {
        if (StringUtils.isBlank(value)) {
            return value;
        }
//        0x4830:0x0211:0x0924:0x2013
//        2013-09-24 11:48:30
        String[] times = value.split(":");
        if (times.length < 4) {
            return value;
        }
        String minuteSecond = times[0];
        String weekHour = times[1];
        String monthDay = times[2];
        String year = times[3];

//        minuteSecond = Integer.toHexString(NumberUtils.createInteger(minuteSecond));
//        weekHour = Integer.toHexString(NumberUtils.createInteger(weekHour));
//        monthDay = Integer.toHexString(NumberUtils.createInteger(monthDay));
//        year = Integer.toHexString(NumberUtils.createInteger(year));

        minuteSecond = StringUtils.leftPad(minuteSecond, 4, '0');
        weekHour = StringUtils.leftPad(weekHour, 4, '0');
        monthDay = StringUtils.leftPad(monthDay, 4, '0');

        return year + "-" + StringUtils.substring(monthDay, 0, 2) + "-" +
                StringUtils.substring(monthDay, 2) + " " + StringUtils.substring(weekHour, 2) + ":" +
                StringUtils.substring(minuteSecond, 0, 2) + ":" + StringUtils.substring(minuteSecond, 2);
    }

    @Override
    public void decode(Map<String, Object> commandPointMap, ModbusMessage.MessagePoint point) {
        point.setValue(this.decode(commandPointMap, MapUtil.getBool(commandPointMap, "use_hex", Boolean.FALSE) ? point.getOriginalValue() : point.getValue()));
    }
}
