package com.isu.gaswellwatch.modbus.data.decode.impl.weps;

import cn.hutool.core.map.MapUtil;
import com.isu.gaswellwatch.modbus.data.ModbusMessage;
import com.isu.gaswellwatch.modbus.data.decode.DecodeHandler;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.math.NumberUtils;
import org.springframework.stereotype.Component;

import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @author <a href="mailto:shilong.wang@alpha-ess.com">王仕龙</a>
 * 2025/2/22 00:38
 */
@Component(WepsRemainingLocalTimeDecodeHandler.NAME + DecodeHandler.DECODE_NAME)
public class WepsRemainingLocalTimeDecodeHandler implements DecodeHandler {
    public static final String NAME = "wepsRemainingLocalTime";

    @Override
    public String decode(Map<String, Object> commandPointMap, String value) {
        if (StringUtils.isBlank(value)) {
            return value;
        }
        // 0x0930:0x0001
        // 0.1:09:30
        String[] times = value.split(":");
        if (times.length < 2) {
            return value;
        }
        String minuteSecond = times[0];
        String dayHour = times[1];

        minuteSecond = StringUtils.leftPad(minuteSecond, 4, '0');
        dayHour = StringUtils.leftPad(dayHour, 4, '0');

        long daySeconds = TimeUnit.DAYS.toSeconds(NumberUtils.createLong(StringUtils.substring(dayHour, 0, 2)));
        long hourSeconds = TimeUnit.HOURS.toSeconds(NumberUtils.createLong(StringUtils.substring(dayHour, 2)));
        long minuteSeconds = TimeUnit.HOURS.toSeconds(NumberUtils.createLong(StringUtils.substring(minuteSecond, 0, 2)));
        long seconds = TimeUnit.HOURS.toSeconds(NumberUtils.createLong(StringUtils.substring(minuteSecond, 2)));

        long totalSeconds = daySeconds + hourSeconds + minuteSeconds + seconds;
        long hours = TimeUnit.SECONDS.toHours(totalSeconds);
        long remainingSeconds = totalSeconds - TimeUnit.HOURS.toSeconds(hours);
        long minutes = TimeUnit.SECONDS.toMinutes(remainingSeconds);
        remainingSeconds = remainingSeconds - TimeUnit.MINUTES.toSeconds(minutes);
        return String.format("%02d:%02d:%02d", hours, minutes, remainingSeconds);
    }

    @Override
    public void decode(Map<String, Object> commandPointMap, ModbusMessage.MessagePoint point) {
        point.setValue(this.decode(commandPointMap, MapUtil.getBool(commandPointMap, "use_hex", Boolean.FALSE) ? point.getOriginalValue() : point.getValue()));
    }
}
