package com.isu.gaswellwatch.utils;


import org.apache.commons.lang3.StringUtils;

import java.util.Map;
import java.util.TreeMap;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.stream.Collectors;

/**
 * @author <a href="mailto:shilong.wang@alpha-ess.com">王仕龙</a>
 * 2025/2/25 20:10
 */
public class ByteOrderUtils {

    /**
     * @param hexString
     * @param byteOrder 可选值：AB,BA,ABCD,CDAB,DCBA等
     * @return
     */
    public static String decode(String hexString, String byteOrder) {
        if (StringUtils.isBlank(byteOrder) || StringUtils.equalsAnyIgnoreCase(byteOrder, "AB", "ABCD")) {
            return hexString;
        }
        AtomicInteger atomicInteger = new AtomicInteger(0);
        Map<Character, Integer> byteOrderMap = new TreeMap<>(Character::compare);
        byteOrder.chars().forEach(i -> byteOrderMap.put((char) i, atomicInteger.getAndIncrement()));
        int size = hexString.length() / 2;
        String[] byteOrderChars = new String[size];
        for (int i = 0; i < size; i++) {
            byteOrderChars[i] = hexString.substring(i * 2, i * 2 + 2);
        }
        if (hexString.length() >= byteOrder.length()) {
            return byteOrderMap.values().stream().map(idx -> byteOrderChars[idx]).collect(Collectors.joining());
        } else {
            return hexString;
        }
    }


    /**
     * @param hexString
     * @param byteOrder 可选值：AB,BA,ABCD,CDAB,DCBA等
     * @return
     */
    public static String encode(String hexString, String byteOrder) {
        if (StringUtils.isBlank(byteOrder) || StringUtils.equalsAnyIgnoreCase(byteOrder, "AB", "ABCD")) {
            return hexString;
        }
        int length = byteOrder.length() * 2;
        if (hexString.length() < length) {
            hexString = StringUtils.leftPad(hexString, length, '0');
        }
        AtomicInteger atomicInteger = new AtomicInteger(0);
        Map<Character, Integer> byteOrderMap = new TreeMap<>(Character::compare);
        byteOrder.chars().forEach(i -> byteOrderMap.put((char) i, atomicInteger.getAndIncrement()));
        int size = hexString.length() / 2;
        String[] byteOrderChars = new String[size];
        for (int i = 0; i < size; i++) {
            byteOrderChars[i] = hexString.substring(i * 2, i * 2 + 2);
        }
        if (hexString.length() >= byteOrder.length()) {
            return byteOrderMap.values().stream().map(idx -> byteOrderChars[idx]).collect(Collectors.joining());
        } else {
            return hexString;
        }
    }


}
