CREATE TABLE `$TableName$`
(
    `id`                                   bigint   NOT NULL COMMENT '主键',
    `device_id`                            int      NOT NULL COMMENT '设备标识',
    `created_time`                         datetime NOT NULL COMMENT '数据落库时间',
    `collection_time`                      datetime NOT NULL COMMENT '采集指令下发时间',
    `receive_time`                         datetime NOT NULL COMMENT '接收到数据时间',
    `report_status`                        int NULL DEFAULT NULL COMMENT '报表状态 - 0:无报表数据; 1:有分钟记录; 2:有小时记录; 3:有日志记录; 4:有生产记录',
    `current_status`                       int NULL DEFAULT NULL COMMENT '当前状态 - 0:关井; 1:上升; 2:续流; 3:停机',
    `current_time`                         datetime NULL DEFAULT NULL COMMENT '当前时间 - "控制器时间。示例：0x4830:0x0211:0x0924:0x2013。结果：2013-09-24 11:48:30"',
    `remaining_time`                       varchar(10) NULL DEFAULT NULL COMMENT '剩余时间 - "组合后时间格式：天.小时:分钟:秒。示例：0x0930:0x0001。结果：0.1:09:30"',
    `current_status_0x`                    varchar(10) NULL DEFAULT NULL COMMENT '当前状态0x - 0x8000:关井；0x8001:上升；0x8002:续流；0x8003:停机',
    `oil_pressure`                         decimal(12, 4) NULL DEFAULT NULL COMMENT '油压 - 单位：MPa',
    `oil_pressure_temperature`             decimal(12, 4) NULL DEFAULT NULL COMMENT '油压表测量温度 - 单位：℃',
    `cas_pressure`                         decimal(12, 4) NULL DEFAULT NULL COMMENT '套压 - 单位：MPa',
    `cas_pressure_temperature`             decimal(12, 4) NULL DEFAULT NULL COMMENT '套压测量温度 - 单位：℃',
    `quantity_of_electricity`              decimal(12, 4) NULL DEFAULT NULL COMMENT '控制器电量 - 单位：%',
    `pluger_rising_speed`                  decimal(12, 4) NULL DEFAULT NULL COMMENT '柱塞上升速度 - 单位：米/分钟',
    `gas_well_number`                      int NULL DEFAULT NULL COMMENT '气井编号',
    `depth_of_lock_device`                 int NULL DEFAULT NULL COMMENT '卡定器深度 - 单位：米',
    `arriving_sensor`                      int NULL DEFAULT NULL COMMENT '到达传感器 - 0/1：禁用/启用',
    `zigbee`                               int NULL DEFAULT NULL COMMENT 'Zigbee - 0/1：禁用/启用',
    `pulse_width`                          int NULL DEFAULT NULL COMMENT '脉冲宽度 - 驱动电磁阀使用',
    `plug_rising_speed`                    int NULL DEFAULT NULL COMMENT '上升速度 - 米/分钟',
    `plug_too_fast_speed`                  int NULL DEFAULT NULL COMMENT '过快速度 - 米/分钟',
    `plug_too_slow_speed`                  int NULL DEFAULT NULL COMMENT '过缓速度 - 米/分钟',
    `gas_well_name`                        varchar(100) NULL DEFAULT NULL COMMENT '气井名称',
    `oil_and_cas_data_collection_interval` int NULL DEFAULT NULL COMMENT '油、套压数据采集间隔 - 0：每5秒采样；1：每10秒采样；2：每15秒采样；3：每30秒采样；4：每1秒采样；5：每2秒采样；6：每3秒采样；7：每4秒采样',
    `store_data_interval_on_open_well`     int NULL DEFAULT NULL COMMENT '数据存储间隔（开井期间） - 0：每1分钟存储；1：每5分钟存储；2：每10分钟存储；3：每15分钟存储；4：每30秒存储；5：每15秒存储；6：每5秒存储',
    `store_data_interval_on_close_well`    int NULL DEFAULT NULL COMMENT '数据存储间隔（关井期间） - 0：每1分钟存储；1：每5分钟存储；2：每10分钟存储；3：每15分钟存储；4：每30秒存储；5：每15秒存储；6：每5秒存储',
    `communication_power_threshold`        decimal(12, 4) NULL DEFAULT NULL COMMENT '通信电量门限 - Zigbee通讯使用',
    `reserve1`                             int NULL DEFAULT NULL COMMENT '保留 - Zigbee通讯使用',
    `start_time_of_daytime`                int NULL DEFAULT NULL COMMENT '白天起始时间 - Zigbee通讯使用',
    `end_time_of_daytime`                  int NULL DEFAULT NULL COMMENT '白天结束时间 - Zigbee通讯使用',
    `control_work_time`                    int NULL DEFAULT NULL COMMENT '控制器工作状态 - 0：生产模式；1：常开模式；2：常关模式',
    `produce_mode`                         int NULL DEFAULT NULL COMMENT '生产制度设置 - 0：定时开关井；1：时间优化模式；2：压力微升模式；3：压力回升模式；4：压力跌落模式',
    `plunger_rise_time`                    varchar(10) NULL DEFAULT NULL COMMENT '上升时间 - 单位：秒',
    `dangerous_rise_time`                  varchar(10) NULL DEFAULT NULL COMMENT '危险上升时间 - 单位：秒',
    `too_fast_rise_time`                   varchar(10) NULL DEFAULT NULL COMMENT '过快上升时间 - 单位：秒',
    `too_slow_rise_time`                   varchar(10) NULL DEFAULT NULL COMMENT '过缓上升时间 - 单位：秒',
    `too_fast_count`                       int NULL DEFAULT NULL COMMENT '过快次数',
    `too_fast_raise_open_well_time`        varchar(10) NULL DEFAULT NULL COMMENT '过快增加开井时间 - 单位：秒',
    `too_fast_lower_close_well_time`       varchar(10) NULL DEFAULT NULL COMMENT '过快减少关井时间 - 单位：秒',
    `too_slow_lower_open_well_time`        varchar(10) NULL DEFAULT NULL COMMENT '过缓减少开井时间 - 单位：秒',
    `too_slow_raise_close_well_time`       varchar(10) NULL DEFAULT NULL COMMENT '过缓增加关井时间 - 单位：秒',
    `check_stability_time`                 varchar(10) NULL DEFAULT NULL COMMENT '检测稳定时间 - 单位：秒',
    `min_close_well_time`                  varchar(10) NULL DEFAULT NULL COMMENT '最小关井时间 - 单位：秒',
    `max_close_well_time`                  varchar(10) NULL DEFAULT NULL COMMENT '最大关井时间 - 单位：秒',
    `well_close_time_not_reached_duration` varchar(10) NULL DEFAULT NULL COMMENT '未到达关井时间 - 单位：秒',
    `min_open_well_time`                   varchar(10) NULL DEFAULT NULL COMMENT '最小开井时间 - 单位：秒',
    `max_open_well_time`                   varchar(10) NULL DEFAULT NULL COMMENT '最大开井时间 - 单位：秒',
    `after_flow_time`                      varchar(10) NULL DEFAULT NULL COMMENT '续流时间 - 单位：秒',
    `not_reached_flow_time`                varchar(10) NULL DEFAULT NULL COMMENT '未到续流时间 - 单位：秒',
    `close_time`                           varchar(10) NULL DEFAULT NULL COMMENT '关井时间 - 单位：秒',
    `open_time`                            varchar(10) NULL DEFAULT NULL COMMENT '开井时间 - 单位：秒',
    `open_pressure`                        decimal(12, 4) NULL DEFAULT NULL COMMENT '开井压力 - 单位：MPa',
    `close_pressure`                       decimal(12, 4) NULL DEFAULT NULL COMMENT '关井压力 - 单位：MPa',
    `little_rise_pressure`                 decimal(12, 4) NULL DEFAULT NULL COMMENT '微升压力 - 单位：MPa',
    `gas_collection_mode`                  int NULL DEFAULT NULL COMMENT '集气模式 - 0：低压集气模式；1：高压集气模式',
    `reserve2`                             int NULL DEFAULT NULL COMMENT '保留',
    `protection_pressure`                  decimal(12, 4) NULL DEFAULT NULL COMMENT '保护压力 - 单位：MPa',
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `udx_device_create_time` (`device_id` ASC, `collection_time` ASC) USING BTREE COMMENT '设备采集数据唯一键'
) ENGINE = InnoDB COMMENT = '维尔普斯设备ID：$DeviceId$的采集数据'